<?php

namespace Drupal\Tests\markdown\Functional;

use Drupal\filter\Entity\FilterFormat;
use Drupal\filter\FilterFormatInterface;
use Drupal\markdown\Plugin\Filter\FilterMarkdownInterface;

/**
 * Makes sure that the markdown filter can be enabled for a text format.
 *
 * @group markdown
 */
class FilterAdminTest extends MarkdownBrowserTestBase {

  /**
   * A user with administration permissions.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer filters',
      'access site reports',
    ]);

    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests creating a text format with markdown filter enabled.
   */
  public function testEnableMarkdownFilter() {
    // Add text format.
    $this->drupalGet('admin/config/content/formats/add');

    $format_id = $this->randomMachineName();
    $name = $this->randomMachineName();
    $edit = [
      'format' => $format_id,
      'name' => $name,
      'filters[markdown][status]' => 1,
    ];
    $this->submitForm($edit, 'Save configuration');

    // Check that the filter has been created.
    $format = FilterFormat::load($format_id);
    $this->assertInstanceof(FilterFormatInterface::class, $format);

    // And check that markdown filter is enabled.
    $markdown = $format->filters()->get('markdown');
    $this->assertInstanceof(FilterMarkdownInterface::class, $markdown);
    $this->assertTrue($markdown->isEnabled());
  }

}
